@@ -1,6 +1,7 @@
 use libc::c_int;
-use object::*;
-use pyport::Py_ssize_t;
+
+use crate::object::*;
+use crate::pyport::Py_ssize_t;
 
 //enum PySetObject { /* representation hidden */ }
 
